@@ -1,4 +1,3 @@
-# -*- coding: UTF-8 -*-
 """Database Utility Tests"""
 import copy
 import os
@@ -17,23 +16,30 @@ class TestDatabase:
     connected = False
     started = False
     stopped = False
-    dbpath = join('tests', 'test_database.db')
-    params = {'database': 'mydatabase', 'host': 'myserver', 'port': 1234, 'username': 'myuser', 'password': 'mypass',
-              'driver': 'postgres'}
-    sqlalchemy_url = 'postgres://myuser:mypass@myserver:1234/mydatabase'
+    dbpath = join("tests", "test_database.db")
+    params = {
+        "database": "mydatabase",
+        "host": "myserver",
+        "port": 1234,
+        "username": "myuser",
+        "password": "mypass",
+        "driver": "postgres",
+    }
+    sqlalchemy_url = "postgres://myuser:mypass@myserver:1234/mydatabase"
 
-    @pytest.fixture(scope='function')
+    @pytest.fixture(scope="function")
     def nodatabase(self):
         try:
             os.remove(TestDatabase.dbpath)
         except OSError:
             pass
-        return 'sqlite:///%s' % TestDatabase.dbpath
+        return f"sqlite:///{TestDatabase.dbpath}"
 
-    @pytest.fixture(scope='function')
+    @pytest.fixture(scope="function")
     def mock_psycopg2(self, monkeypatch):
         def connect(**kwargs):
             if TestDatabase.connected:
+
                 class Connection:
                     @staticmethod
                     def close():
@@ -44,9 +50,9 @@ class TestDatabase:
                 TestDatabase.connected = True
                 raise psycopg2.OperationalError
 
-        monkeypatch.setattr(psycopg2, 'connect', connect)
+        monkeypatch.setattr(psycopg2, "connect", connect)
 
-    @pytest.fixture(scope='function')
+    @pytest.fixture(scope="function")
     def mock_SSHTunnelForwarder(self, monkeypatch):
         def init(*args, **kwargs):
             return None
@@ -57,24 +63,24 @@ class TestDatabase:
         def stop(_):
             TestDatabase.stopped = True
 
-        monkeypatch.setattr(SSHTunnelForwarder, '__init__', init)
-        monkeypatch.setattr(SSHTunnelForwarder, 'start', start)
-        monkeypatch.setattr(SSHTunnelForwarder, 'stop', stop)
-        monkeypatch.setattr(SSHTunnelForwarder, 'local_bind_host', '0.0.0.0')
-        monkeypatch.setattr(SSHTunnelForwarder, 'local_bind_port', 12345)
+        monkeypatch.setattr(SSHTunnelForwarder, "__init__", init)
+        monkeypatch.setattr(SSHTunnelForwarder, "start", start)
+        monkeypatch.setattr(SSHTunnelForwarder, "stop", stop)
+        monkeypatch.setattr(SSHTunnelForwarder, "local_bind_host", "0.0.0.0")
+        monkeypatch.setattr(SSHTunnelForwarder, "local_bind_port", 12345)
 
         def get_session(_, db_url):
             class Session:
-                bind = namedtuple('Bind', 'engine')
+                bind = namedtuple("Bind", "engine")
 
                 def close(self):
                     return None
 
-            Session.bind.engine = namedtuple('Engine', 'url')
+            Session.bind.engine = namedtuple("Engine", "url")
             Session.bind.engine.url = db_url
             return Session()
 
-        monkeypatch.setattr(Database, 'get_session', get_session)
+        monkeypatch.setattr(Database, "get_session", get_session)
 
     def test_get_params_from_sqlalchemy_url(self):
         result = Database.get_params_from_sqlalchemy_url(TestDatabase.sqlalchemy_url)
@@ -86,17 +92,25 @@ class TestDatabase:
 
     def test_wait_for_postgres(self, mock_psycopg2):
         TestDatabase.connected = False
-        wait_for_postgres('mydatabase', 'myserver', 5432, 'myuser', 'mypass')
+        wait_for_postgres("mydatabase", "myserver", 5432, "myuser", "mypass")
         assert TestDatabase.connected is True
 
     def test_get_session(self, nodatabase):
-        with Database(database=TestDatabase.dbpath, port=None, driver='sqlite') as dbsession:
+        with Database(
+            database=TestDatabase.dbpath, port=None, driver="sqlite"
+        ) as dbsession:
             assert str(dbsession.bind.engine.url) == nodatabase
 
     def test_get_session_ssh(self, mock_psycopg2, mock_SSHTunnelForwarder):
-        with Database(ssh_host='mysshhost', **TestDatabase.params) as dbsession:
-            assert str(dbsession.bind.engine.url) == 'postgres://myuser:mypass@0.0.0.0:12345/mydatabase'
+        with Database(ssh_host="mysshhost", **TestDatabase.params) as dbsession:
+            assert (
+                str(dbsession.bind.engine.url)
+                == "postgres://myuser:mypass@0.0.0.0:12345/mydatabase"
+            )
         params = copy.deepcopy(TestDatabase.params)
-        del params['password']
-        with Database(ssh_host='mysshhost', ssh_port=25, **params) as dbsession:
-            assert str(dbsession.bind.engine.url) == 'postgres://myuser@0.0.0.0:12345/mydatabase'
+        del params["password"]
+        with Database(ssh_host="mysshhost", ssh_port=25, **params) as dbsession:
+            assert (
+                str(dbsession.bind.engine.url)
+                == "postgres://myuser@0.0.0.0:12345/mydatabase"
+            )
